==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QWGLContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_WIN)



#endif // defined(Q_OS_WIN)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QWGLContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QWGLContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QWGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QWGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QWGLContext::nativeContext()const", __qt_this)
        HGLRC __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 0);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QWGLContext::fromNative(HGLRC,HWND,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QWGLContext_00024Impl_fromNative_1native_1HGLRC_1HWND_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject context0,
 jobject window1,
 QtJambiNativeID shareContext2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QWGLContext::fromNative(HGLRC,HWND,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        HGLRC __qt_context0 = reinterpret_cast<HGLRC >(QtJambiAPI::convertQNativePointerToNative(__jni_env, context0, 0));
        HWND __qt_window1 = reinterpret_cast<HWND >(QtJambiAPI::convertQNativePointerToNative(__jni_env, window1, 0));
        QOpenGLContext* __qt_shareContext2 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext2);
        QOpenGLContext* __qt_return_value = QNativeInterface::QWGLContext::fromNative(__qt_context0, __qt_window1, __qt_shareContext2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(context0)
        Q_UNUSED(window1)
        Q_UNUSED(shareContext2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QWGLContext::openGLModuleHandle()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QWGLContext_00024Impl_openGLModuleHandle__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QWGLContext::openGLModuleHandle()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        HMODULE __qt_return_value = QNativeInterface::QWGLContext::openGLModuleHandle();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 0);
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QWGLContext(){
    using namespace RegistryAPI;

#if defined(Q_OS_WIN)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QWGLContext>("QNativeInterface::QWGLContext", "io/qt/gui/nativeinterface/QWGLContext");
    registerNativeInterface<QNativeInterface::QWGLContext>("io/qt/gui/nativeinterface/QWGLContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QWGLContext* _object = dynamic_cast<QNativeInterface::QWGLContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QWGLContext *object = reinterpret_cast<QNativeInterface::QWGLContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QWGLContext *object = reinterpret_cast<const QNativeInterface::QWGLContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_WIN)

    registerNativeInterface("io/qt/gui/nativeinterface/QWGLContext", {});

#endif //defined(Q_OS_WIN)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QWGLContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_WIN)



#endif // defined(Q_OS_WIN)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QWGLContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QWGLContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QWGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QWGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QWGLContext::nativeContext()const", __qt_this)
        HGLRC __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 0);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QWGLContext::fromNative(HGLRC,HWND,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QWGLContext_00024Impl_fromNative_1native_1HGLRC_1HWND_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject context0,
 jobject window1,
 QtJambiNativeID shareContext2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QWGLContext::fromNative(HGLRC,HWND,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        HGLRC __qt_context0 = reinterpret_cast<HGLRC >(QtJambiAPI::convertQNativePointerToNative(__jni_env, context0));
        HWND __qt_window1 = reinterpret_cast<HWND >(QtJambiAPI::convertQNativePointerToNative(__jni_env, window1));
        QOpenGLContext* __qt_shareContext2 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext2);
        QOpenGLContext* __qt_return_value = QNativeInterface::QWGLContext::fromNative(__qt_context0, __qt_window1, __qt_shareContext2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(context0)
        Q_UNUSED(window1)
        Q_UNUSED(shareContext2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QWGLContext::openGLModuleHandle()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QWGLContext_00024Impl_openGLModuleHandle__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QWGLContext::openGLModuleHandle()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        HMODULE __qt_return_value = QNativeInterface::QWGLContext::openGLModuleHandle();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 0);
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QWGLContext(){
    using namespace RegistryAPI;

#if defined(Q_OS_WIN)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QWGLContext>("QNativeInterface::QWGLContext", "io/qt/gui/nativeinterface/QWGLContext");
    registerNativeInterface<QNativeInterface::QWGLContext>("io/qt/gui/nativeinterface/QWGLContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QWGLContext* _object = dynamic_cast<QNativeInterface::QWGLContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QWGLContext *object = reinterpret_cast<QNativeInterface::QWGLContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QWGLContext *object = reinterpret_cast<const QNativeInterface::QWGLContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_WIN)

    registerNativeInterface("io/qt/gui/nativeinterface/QWGLContext", {});

#endif //defined(Q_OS_WIN)

}
